<?php

declare(strict_types=1);

namespace Mm\Masterfilter\Controller;


/**
 * This file is part of the "masterfilter" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * (c) 2022 Andreas Jud <ajud@millemedia.de>, Millemedia GmbH
 */

/**
 * MfproductsController
 */
class MfproductsController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController
{

    /**
     * mfproductsRepository
     *
     * @var \Mm\Masterfilter\Domain\Repository\MfproductsRepository
     */
    protected $mfproductsRepository = null;

    /**
     * @param \Mm\Masterfilter\Domain\Repository\MfproductsRepository $mfproductsRepository
     */
    public function injectMfproductsRepository(\Mm\Masterfilter\Domain\Repository\MfproductsRepository $mfproductsRepository)
    {
        $this->mfproductsRepository = $mfproductsRepository;
    }

    /**
     * mediaRepository
     *
     * @var \Mm\Masterfilter\Domain\Repository\MediaRepository
     */
    protected $mediaRepository = null;

    /**
     * @param \Mm\Masterfilter\Domain\Repository\MediaRepository $mediaRepository
     */
    public function injectMediaRepository(\Mm\Masterfilter\Domain\Repository\MediaRepository $mediaRepository)
    {
        $this->mediaRepository = $mediaRepository;
    }

    /**
     * filterMediaTypeRepository
     *
     * @var \Mm\Masterfilter\Domain\Repository\FilterMediaTypeRepository
     */
    protected $filterMediaTypeRepository = null;

    /**
     * @param \Mm\Masterfilter\Domain\Repository\FilterMediaTypeRepository $filterMediaTypeRepository
     */
    public function injectFilterMediaTypeRepository(\Mm\Masterfilter\Domain\Repository\FilterMediaTypeRepository $filterMediaTypeRepository)
    {
        $this->filterMediaTypeRepository = $filterMediaTypeRepository;
    }

    /**
     * marketsRepository
     *
     * @var \Mm\Masterfilter\Domain\Repository\MarketsRepository
     */
    protected $marketsRepository = null;

    /**
     * @param \Mm\Masterfilter\Domain\Repository\MarketsRepository $marketsRepository
     */
    public function injectMarketsRepository(\Mm\Masterfilter\Domain\Repository\MarketsRepository $marketsRepository)
    {
        $this->marketsRepository = $marketsRepository;
    }

    /**
     * applicationsRepository
     *
     * @var \Mm\Masterfilter\Domain\Repository\ApplicationsRepository
     */
    protected $applicationsRepository = null;

    /**
     * @param \Mm\Masterfilter\Domain\Repository\ApplicationsRepository $applicationsRepository
     */
    public function injectApplicationsRepository(\Mm\Masterfilter\Domain\Repository\ApplicationsRepository $applicationsRepository)
    {
        $this->applicationsRepository = $applicationsRepository;
    }

    /**
     * action list
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function listAction(): \Psr\Http\Message\ResponseInterface
    {
    	if ($this->settings['pcat']) {
	    	$filter = $this->request->getArguments();
	        if ($this->settings['pcat']) {
	        		if ($filter['mfmedia'] || $filter['mffiltermediatype'] || $filter['mfmarket'] || $filter['mfapplication']) {
	        			$mfproducts = $this->mfproductsRepository->findByDemanded(intval($this->settings['pcat']), intval($filter['mfmedia']), intval($filter['mffiltermediatype']), intval($filter['mfmarket']), intval($filter['mfapplication']));
	        		} else {
	        			$mfproducts = $this->mfproductsRepository->findByProductType(intval($this->settings['pcat']));
	        		}
	        } else {
	        	$mfproducts = $this->mfproductsRepository->findAll();
	        }
			//$mfproducts = $this->mfproductsRepository->findByDemanded(intval($this->settings['pcat']), 2, $mffiltermediatype, $mfmarket, $mfapplication);
			// Store the selected fields
			$selected = [];
			if ($filter['mfmedia']) {
				$selected['media'] = $filter['mfmedia'];
			} else {
				$selected['media'] = 0;
			}
			if ($filter['mffiltermediatype']) {
				$selected['fmt'] = $filter['mffiltermediatype'];
			} else {
				$selected['fmt'] = 0;
			}
			if ($filter['mfmarket']) {
				$selected['market'] = $filter['mfmarket'];
			} else {
				$selected['market'] = 0;
			}
			if ($filter['mfapplication']) {
				$selected['app'] = $filter['mfapplication'];
			} else {
				$selected['app'] = 0;
			}
			// Get all existing filter uids to avoid empty resonse
	        $mfmedia = [];
	        $mffiltermediatype = [];
	        $mfmarkets = [];
	        $mfapplications = [];
	        foreach ($mfproducts as $product) {
	        	if ($product->getMedia()) {
	        		foreach ($product->getMedia() as $item) {
	        			if (!$this->in_array_r($item->getUid(),$mfmedia)) {
	        				$itemtmp['uid'] = $item->getUid();
	        				$itemtmp['name'] = $item->getName();
	        				$mfmedia[] = $itemtmp;
	        			}
	        		}
	        	}
	        }
	        unset($product);
	        unset($item);
	        unset($itemtmp);
	        foreach ($mfproducts as $product) {
	        	if ($product->getFilterMediaType()) {
	        		foreach ($product->getFilterMediaType() as $item) {
	        			if (!$this->in_array_r($item->getUid(),$mffiltermediatype)) {
	         				$itemtmp['uid'] = $item->getUid();
	        				$itemtmp['name'] = $item->getName();
	        				$mffiltermediatype[] = $itemtmp;
	        			}
	        		}
	        	}
	        }
	        unset($product);
	        unset($item);
	        unset($itemtmp);
	        foreach ($mfproducts as $product) {
	        	if ($product->getMarkets()) {
	        		foreach ($product->getMarkets() as $item) {
	        			if (!$this->in_array_r($item->getUid(),$mfmarkets)) {
	         				$itemtmp['uid'] = $item->getUid();
	        				$itemtmp['name'] = $item->getName();
	        				$mfmarkets[] = $itemtmp;
	        			}
	        		}
	        	}
	        }
	        unset($product);
	        unset($item);
	        unset($itemtmp);
	        foreach ($mfproducts as $product) {
	        	if ($product->getApplications()) {
	        		foreach ($product->getApplications() as $item) {
	        			if (!$this->in_array_r($item->getUid(),$mfapplications)) {
		         				$itemtmp['uid'] = $item->getUid();
		        				$itemtmp['name'] = $item->getName();
		        				$itemtmp['market'] = $item->getMarket()->getUid();
		        				$mfapplications[] = $itemtmp;	        					
	        			}
	        		}
	        	}
	        }
	        
	        unset($product);
	        unset($item);
	        unset($itemtmp);
	        if ($filter['mfmarket']) {
	        	foreach ($mfapplications as $key => $item) {
	        		if (intval($filter['mfmarket']) != $item['market'] ) {
	        			unset($mfapplications[$key]);
	        		}
	        	}
	        }
	        unset($item);
	        unset($key);


			if ($mfmedia) {
				usort($mfmedia, function($a, $b) {
				    return $a['name'] <=> $b['name'];
				});				
			}
			if ($mfapplications) {
				usort($mfapplications, function($a, $b) {
				    return $a['name'] <=> $b['name'];
				});
				
			}
			if ($mfmarkets) {
				usort($mfmarkets, function($a, $b) {
				    return $a['name'] <=> $b['name'];
				});
			}
			if ($mffiltermediatype) {
				usort($mffiltermediatype, function($a, $b) {
				    return $a['name'] <=> $b['name'];
				});
			}

			
	        //$mfmedia = $this->mediaRepository->findAll();
	        //$mffiltermediatype = $this->filterMediaTypeRepository->findAll();
	        //$mfmarkets = $this->marketsRepository->findAll();
	        //$mfapplications = $this->applicationsRepository->findAll();
	        
	        $this->view->assignMultiple([
	        	'mfproducts' => $mfproducts,
	        	'mfmedia' => $mfmedia,
	        	'mffiltermediatype' => $mffiltermediatype,
	        	'mfmarkets' => $mfmarkets,
	        	'mfapplications' => $mfapplications,
	        	'selected' => $selected,
	        	'filter' => $filter
	        ]);

	        
	        return $this->htmlResponse();
    		
    	}
    	if ($this->settings['papp']) {
	    	if ($this->settings['papp']) {
	    		 $mfproducts = $this->mfproductsRepository->findRelated(intval($this->settings['papp']));
	    		 //$mfproducts = $this->mfproductsRepository->findByApplications(intval($this->settings['papp']));
	    	}
	    	$this->view->assign('mfproducts', $mfproducts);
	        return $this->htmlResponse();    		
    	}
    }

    /**
     * action show
     *
     * @param \Mm\Masterfilter\Domain\Model\Mfproducts $mfproducts
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function showAction(\Mm\Masterfilter\Domain\Model\Mfproducts $mfproducts): \Psr\Http\Message\ResponseInterface
    {
        $this->view->assign('mfproducts', $mfproducts);
        return $this->htmlResponse();
    }

    /**
     * action listProd
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function listProdAction(): \Psr\Http\Message\ResponseInterface
    {
        return $this->htmlResponse();
    }

    /**
     * action listMed
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function listMedAction(): \Psr\Http\Message\ResponseInterface
    {
        return $this->htmlResponse();
    }

    /**
     * action listMar
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function listMarAction(): \Psr\Http\Message\ResponseInterface
    {
        return $this->htmlResponse();
    }

    /**
     * action listApp
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function listAppAction(): \Psr\Http\Message\ResponseInterface
    {
    	if ($this->settings['papp']) {
    		 $mfproducts = $this->mfproductsRepository->findRelated(intval($this->settings['papp']));
    		 //$mfproducts = $this->mfproductsRepository->findByApplications(intval($this->settings['papp']));
    	}
    	$this->view->assign('mfproducts', $mfproducts);
        return $this->htmlResponse();
    }

    /**
     * action listFilType
     *
     * @return \Psr\Http\Message\ResponseInterface
     */
    public function listFilTypeAction(): \Psr\Http\Message\ResponseInterface
    {
        return $this->htmlResponse();
    }
    
	public function in_array_r($needle, $haystack, $strict = false) {
	    foreach ($haystack as $item) {
	        if (($strict ? $item === $needle : $item == $needle) || (is_array($item) && $this->in_array_r($needle, $item, $strict))) {
	            return true;
	        }
	    }

	    return false;
	}

    
}



