<?php

declare(strict_types=1);

namespace Mm\Masterfilter\Domain\Repository;

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Core\Database\ConnectionPool;
use TYPO3\CMS\Core\Database\Query\QueryBuilder;

/**
 * This file is part of the "masterfilter" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * (c) 2022 Andreas Jud <ajud@millemedia.de>, Millemedia GmbH
 */

/**
 * The repository for Mfproducts
 */
class MfproductsRepository extends \TYPO3\CMS\Extbase\Persistence\Repository
{

    /**
     * @var array
     */
    protected $defaultOrderings = ['productHeader' => \TYPO3\CMS\Extbase\Persistence\QueryInterface::ORDER_ASCENDING];

    /**
     * @param $pcat
     * @param $mfmedia
     * @param $mffiltermediatype
     * @param $mfmarket
     * @param $mfapplication
     */
    public function findByDemanded($pcat = null, $mfmedia = null, $mffiltermediatype = null, $mfmarket = null, $mfapplication = null)
    {
        $query = $this->createQuery();
        $constraints = [];
        if ($pcat) {
            $constraints[] = $query->equals('productType', $pcat);
        }
        if ($mfmedia) {
            $constraints[] = $query->contains('media', $mfmedia);
        }
        if ($mffiltermediatype) {
            $constraints[] = $query->contains('filterMediaType', $mffiltermediatype);
        }
        if ($mfmarket) {
            $constraints[] = $query->contains('markets', $mfmarket);
        }
        if ($mfapplication) {
            $constraints[] = $query->contains('applications', $mfapplication);
        }
        $query->matching($query->logicalAnd($constraints));

        //$queryParser = $this->objectManager->get(\TYPO3\CMS\Extbase\Persistence\Generic\Storage\Typo3DbQueryParser::class);
        //\TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($queryParser->convertQueryToDoctrineQueryBuilder($query)->getSQL());
        //\TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($queryParser->convertQueryToDoctrineQueryBuilder($query)->getParameters());



        return $query->execute();
    }

	/**
	 * findRelated - like findByApplication() 
	 *
 	 * @param int $papp The unique id of the object to find
	 */
	public function findRelated(int $papp) 
	{
		$query = $this->createQuery();
		$query->matching($query->contains('applications', $papp));
 
        //$queryParser = $this->objectManager->get(\TYPO3\CMS\Extbase\Persistence\Generic\Storage\Typo3DbQueryParser::class);
        //\TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($queryParser->convertQueryToDoctrineQueryBuilder($query)->getSQL());
        //\TYPO3\CMS\Extbase\Utility\DebuggerUtility::var_dump($queryParser->convertQueryToDoctrineQueryBuilder($query)->getParameters());

		return $query->execute();



/*
	    $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable('tx_masterfilter_domain_model_mfproducts');
	    $resultList = $queryBuilder
	    	->select('*')
	        ->from('tx_masterfilter_domain_model_mfproducts')
	        ->where(
	            $queryBuilder->expr()->in('product_type', $queryBuilder->createNamedParameter($pcat,  \PDO::PARAM_INT)),
	            $queryBuilder->expr()->in('media', $queryBuilder->createNamedParameter(2))
	        )
	        ->executeQuery();
			debug($queryBuilder->getSQL());	
	    return $resultList;
	    */
	}

}
