<?php

declare(strict_types=1);

namespace Mm\Masterfilter\Tests\Unit\Controller;

use PHPUnit\Framework\MockObject\MockObject;
use TYPO3\TestingFramework\Core\AccessibleObjectInterface;
use TYPO3\TestingFramework\Core\Unit\UnitTestCase;
use TYPO3Fluid\Fluid\View\ViewInterface;

/**
 * Test case
 *
 * @author Andreas Jud <ajud@millemedia.de>
 */
class MfproductsControllerTest extends UnitTestCase
{
    /**
     * @var \Mm\Masterfilter\Controller\MfproductsController|MockObject|AccessibleObjectInterface
     */
    protected $subject;

    protected function setUp(): void
    {
        parent::setUp();
        $this->subject = $this->getMockBuilder($this->buildAccessibleProxy(\Mm\Masterfilter\Controller\MfproductsController::class))
            ->onlyMethods(['redirect', 'forward', 'addFlashMessage'])
            ->disableOriginalConstructor()
            ->getMock();
    }

    protected function tearDown(): void
    {
        parent::tearDown();
    }

    /**
     * @test
     */
    public function listActionFetchesAllMfproductsFromRepositoryAndAssignsThemToView(): void
    {
        $allMfproducts = $this->getMockBuilder(\TYPO3\CMS\Extbase\Persistence\ObjectStorage::class)
            ->disableOriginalConstructor()
            ->getMock();

        $mfproductsRepository = $this->getMockBuilder(\Mm\Masterfilter\Domain\Repository\MfproductsRepository::class)
            ->onlyMethods(['findAll'])
            ->disableOriginalConstructor()
            ->getMock();
        $mfproductsRepository->expects(self::once())->method('findAll')->will(self::returnValue($allMfproducts));
        $this->subject->_set('mfproductsRepository', $mfproductsRepository);

        $view = $this->getMockBuilder(ViewInterface::class)->getMock();
        $view->expects(self::once())->method('assign')->with('mfproducts', $allMfproducts);
        $this->subject->_set('view', $view);

        $this->subject->listAction();
    }

    /**
     * @test
     */
    public function showActionAssignsTheGivenMfproductsToView(): void
    {
        $mfproducts = new \Mm\Masterfilter\Domain\Model\Mfproducts();

        $view = $this->getMockBuilder(ViewInterface::class)->getMock();
        $this->subject->_set('view', $view);
        $view->expects(self::once())->method('assign')->with('mfproducts', $mfproducts);

        $this->subject->showAction($mfproducts);
    }
}
